==> 1.0.0.tar.gz: lib/src/sub_types/NonLabelledStatement.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import 'NonLabelledStatements.dart';
import '../main/LocalFunctionDeclaration.dart';
import '../main/SwitchStatement.dart';
import '../main/AssertStatement.dart';
import '../main/TryStatement.dart';
import '../main/ForStatement.dart';
import '../main/Block.dart';

/*
<nonLabelledStatement> ::= <block>
| <localVariableDeclaration>
| <forStatement>
| <whileStatement>
| <doStatement>
| <switchStatement>
| <ifStatement>
| <rethrowStatement>
| <tryStatement>
| <breakStatement>
| <continueStatement>
| <returnStatement>
| <yieldStatement>
| <yieldEachStatement>
| <expressionStatement>
| <assertStatement>
| <localFunctionDeclaration>

See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
Page 145
*/

class NonLabelledStatement extends ParserType {
  int caseNum;
  Block block;
  LocalVariableDeclaration localVariableDeclaration;
  ForStatement forStatement;
  WhileStatement whileStatement;
  DoStatement doStatement;
  SwitchStatement switchStatement;
  IfStatement ifStatement;
  RethrowStatement rethrowStatement;
  TryStatement tryStatement;
  BreakStatement breakStatement;
  ContinueStatement continueStatement;
  ReturnStatement returnStatement;
  YieldStatement yieldStatement;
  YieldEachStatement yieldEachStatement;
  ExpressionStatment expressionStatment;
  AssertStatement assertStatement;
  LocalFunctionDeclaration localFunctionDeclaration;

  NonLabelledStatement(Lexer lexer) {
    // print ('Started NonLabelledStatement');

    int attempt, maxAttempts = 17;
    int snapShot = lexer.currentIndex;
    for (attempt = 0; attempt < maxAttempts; ++attempt) {
      try {
        switch (attempt) {
          case 0: _case0(lexer); break;
          case 1: _case1(lexer); break;
          case 2: _case2(lexer); break;
          case 3: _case3(lexer); break;
          case 4: _case4(lexer); break;
          case 5: _case5(lexer); break;
          case 6: _case6(lexer); break;
          case 7: _case7(lexer); break;
          case 8: _case8(lexer); break;
          case 9: _case9(lexer); break;
          case 10: _case10(lexer); break;
          case 11: _case11(lexer); break;
          case 12: _case12(lexer); break;
          case 13: _case13(lexer); break;
          case 14: _case14(lexer); break;
          case 15: _case15(lexer); break;
          case 16: _case16(lexer); break;
        }

        break;
      }
      on WrongTokenType {
        lexer.setPos(snapShot);
      }
    }

    if (attempt == maxAttempts)
      throw WrongTokenType('Tried all options in NonLabelledStatement: ALL FAILED');

    // print ('Finished NonLabelledStatement');
  }
  
  /* <block> */
  void _case0(Lexer lexer) {
    // print ('Started Block');
    block = Block(lexer);
    // print ('Finished Block');
    caseNum = 0;
  }
  
  /* <localVariableDeclaration> */
  void _case1(Lexer lexer) {
    // print ('Started LocalVariableDeclaration');
    localVariableDeclaration = LocalVariableDeclaration(lexer);
    // print ('Finished LocalVariableDeclaration');
    caseNum = 1;
  }
  
  /* <forStatement> */
  void _case2(Lexer lexer) {
    // print ('Started ForStatement');
    forStatement = ForStatement(lexer);
    // print ('Finished ForStatement');
    caseNum = 2;
  }
  
  /* <whileStatement> */
  void _case3(Lexer lexer) {
    // print ('Started WhileStatement');
    whileStatement = WhileStatement(lexer);
    // print ('Finished WhileStatement');
    caseNum = 3;
  }
  
  /* <doStatement> */
  void _case4(Lexer lexer) {
    // print ('Started DoStatement');
    doStatement = DoStatement(lexer);
    // print ('Finished DoStatement');
    caseNum = 4;
  }
  
  /* <switchStatement> */
  void _case5(Lexer lexer) {
    // print ('Started SwitchStatement');
    switchStatement = SwitchStatement(lexer);
    // print ('Finished SwitchStatement');
    caseNum = 5;
  }
  
  /* <ifStatement> */
  void _case6(Lexer lexer) {
    // // print ('Started IfStatement');
    ifStatement = IfStatement(lexer);
    // print ('Finished IfStatement');
    caseNum = 6;
  }
  
  /* <rethrowStatement> */
  void _case7(Lexer lexer) {
    // print ('Started RethrowStatement');
    rethrowStatement = RethrowStatement(lexer);
    // print ('Finished RethrowStatement');
    caseNum = 7;
  }
  
  /* <tryStatement> */
  void _case8(Lexer lexer) {
    // print ('Started TryStatement');
    tryStatement = TryStatement(lexer);
    // print ('Finished TryStatement');
    caseNum = 8;
  }
  
  /* <breakStatement> */
  void _case9(Lexer lexer) {
    // print ('Started BreakStatement');
    breakStatement = BreakStatement(lexer);
    // print ('Finished BreakStatement');
    caseNum = 9;
  }
  
  /* <continueStatement> */
  void _case10(Lexer lexer) {
    // print ('Started ContinueStatement');
    continueStatement = ContinueStatement(lexer);
    // print ('Finished ContinueStatement');
    caseNum = 10;
  }
  
  /* <returnStatement> */
  void _case11(Lexer lexer) {
    // print ('Started ReturnStatement');
    returnStatement = ReturnStatement(lexer);
    // print ('Finished ReturnStatement');
    caseNum = 11;
  }
  
  /* <yieldStatement> */
  void _case12(Lexer lexer) {
    // print ('Started YieldStatement');
    yieldStatement = YieldStatement(lexer);
    // print ('Finished YieldStatement');
    caseNum = 12;
  }
  
  /* <yieldEachStatement> */
  void _case13(Lexer lexer) {
    // print ('Started YieldEachStatement');
    yieldEachStatement = YieldEachStatement(lexer);
    // print ('Finished YieldEachStatement');
    caseNum = 13;
  }
  
  /* <expressionStatement> */
  void _case14(Lexer lexer) {
    // print ('Started ExpressionStatement');
    expressionStatment = ExpressionStatment(lexer);
    // print ('Finished ExpressionStatement');
    caseNum = 14;
  }

  /* <assertStatement> */
  void _case15(Lexer lexer) {
    // print ('Started AssertStatement');
    assertStatement = AssertStatement(lexer);
    // print ('Finished AssertStatement');
    caseNum = 15;
  }
  
  /* <localFunctionDeclaration */
  void _case16(Lexer lexer) {
    // print ('Started LocalFunctionStatement');
    localFunctionDeclaration = LocalFunctionDeclaration(lexer);
    // print ('Finished LocalFunctionStatement');
    caseNum = 16;
  }

  String toString() {
    switch (caseNum) {
      case 0: return '$block'; break;
      case 1: return '$localVariableDeclaration'; break;
      case 2: return '$forStatement'; break;
      case 3: return '$whileStatement'; break;
      case 4: return '$doStatement'; break;
      case 5: return '$switchStatement'; break;
      case 6: return '$ifStatement'; break;
      case 7: return '$rethrowStatement'; break;
      case 8: return '$tryStatement'; break;
      case 9: return '$breakStatement'; break;
      case 10: return '$continueStatement'; break;
      case 11: return '$returnStatement'; break;
      case 12: return '$yieldStatement'; break;
      case 13: return '$yieldEachStatement'; break;
      case 14: return '$expressionStatment'; break;
      case 15: return '$assertStatement'; break;
      case 16: return '$localFunctionDeclaration'; break;
    }
    return '';
  }

}

==> 1.1.1.tar.gz: lib/src/sub_types/NonLabelledStatement.dart <==
import '../ParserType.dart';
import '../ParserExceptions.dart';
import '../lexer/Lexer.dart';
import 'NonLabelledStatements.dart';
import '../main/LocalFunctionDeclaration.dart';
import '../main/SwitchStatement.dart';
import '../main/AssertStatement.dart';
import '../main/TryStatement.dart';
import '../main/ForStatement.dart';
import '../main/Block.dart';

/// <nonLabelledStatement> ::= <block>
/// | <localVariableDeclaration>
/// | <forStatement>
/// | <whileStatement>
/// | <doStatement>
/// | <switchStatement>
/// | <ifStatement>
/// | <rethrowStatement>
/// | <tryStatement>
/// | <breakStatement>
/// | <continueStatement>
/// | <returnStatement>
/// | <yieldStatement>
/// | <yieldEachStatement>
/// | <expressionStatement>
/// | <assertStatement>
/// | <localFunctionDeclaration>
///
/// See https://dart.dev/guides/language/specifications/DartLangSpec-v2.2.pdf
/// Page 145

class NonLabelledStatement extends ParserType {
  int caseNum;
  Block block;
  LocalVariableDeclaration localVariableDeclaration;
  ForStatement forStatement;
  WhileStatement whileStatement;
  DoStatement doStatement;
  SwitchStatement switchStatement;
  IfStatement ifStatement;
  RethrowStatement rethrowStatement;
  TryStatement tryStatement;
  BreakStatement breakStatement;
  ContinueStatement continueStatement;
  ReturnStatement returnStatement;
  YieldStatement yieldStatement;
  YieldEachStatement yieldEachStatement;
  ExpressionStatment expressionStatment;
  AssertStatement assertStatement;
  LocalFunctionDeclaration localFunctionDeclaration;

  NonLabelledStatement(Lexer lexer) {
    // print ('Started NonLabelledStatement');

    int attempt, maxAttempts = 17;
    int snapShot = lexer.currentIndex;
    for (attempt = 0; attempt < maxAttempts; ++attempt) {
      try {
        switch (attempt) {
          case 0:
            _case0(lexer);
            break;
          case 1:
            _case1(lexer);
            break;
          case 2:
            _case2(lexer);
            break;
          case 3:
            _case3(lexer);
            break;
          case 4:
            _case4(lexer);
            break;
          case 5:
            _case5(lexer);
            break;
          case 6:
            _case6(lexer);
            break;
          case 7:
            _case7(lexer);
            break;
          case 8:
            _case8(lexer);
            break;
          case 9:
            _case9(lexer);
            break;
          case 10:
            _case10(lexer);
            break;
          case 11:
            _case11(lexer);
            break;
          case 12:
            _case12(lexer);
            break;
          case 13:
            _case13(lexer);
            break;
          case 14:
            _case14(lexer);
            break;
          case 15:
            _case15(lexer);
            break;
          case 16:
            _case16(lexer);
            break;
        }

        break;
      } on WrongTokenType {
        lexer.setPos(snapShot);
      }
    }

    if (attempt == maxAttempts) {
      throw WrongTokenType(
          'Tried all options in NonLabelledStatement: ALL FAILED');
    }

    // print ('Finished NonLabelledStatement');
  }

  /// <block>
  void _case0(Lexer lexer) {
    // print ('Started Block');
    block = Block(lexer);
    // print ('Finished Block');
    caseNum = 0;
  }

  /// <localVariableDeclaration>
  void _case1(Lexer lexer) {
    // print ('Started LocalVariableDeclaration');
    localVariableDeclaration = LocalVariableDeclaration(lexer);
    // print ('Finished LocalVariableDeclaration');
    caseNum = 1;
  }

  /// <forStatement>
  void _case2(Lexer lexer) {
    // print ('Started ForStatement');
    forStatement = ForStatement(lexer);
    // print ('Finished ForStatement');
    caseNum = 2;
  }

  /// <whileStatement>
  void _case3(Lexer lexer) {
    // print ('Started WhileStatement');
    whileStatement = WhileStatement(lexer);
    // print ('Finished WhileStatement');
    caseNum = 3;
  }

  /// <doStatement>
  void _case4(Lexer lexer) {
    // print ('Started DoStatement');
    doStatement = DoStatement(lexer);
    // print ('Finished DoStatement');
    caseNum = 4;
  }

  /// <switchStatement>
  void _case5(Lexer lexer) {
    // print ('Started SwitchStatement');
    switchStatement = SwitchStatement(lexer);
    // print ('Finished SwitchStatement');
    caseNum = 5;
  }

  /// <ifStatement>
  void _case6(Lexer lexer) {
    // // print ('Started IfStatement');
    ifStatement = IfStatement(lexer);
    // print ('Finished IfStatement');
    caseNum = 6;
  }

  /// <rethrowStatement>
  void _case7(Lexer lexer) {
    // print ('Started RethrowStatement');
    rethrowStatement = RethrowStatement(lexer);
    // print ('Finished RethrowStatement');
    caseNum = 7;
  }

  /// <tryStatement>
  void _case8(Lexer lexer) {
    // print ('Started TryStatement');
    tryStatement = TryStatement(lexer);
    // print ('Finished TryStatement');
    caseNum = 8;
  }

  /// <breakStatement>
  void _case9(Lexer lexer) {
    // print ('Started BreakStatement');
    breakStatement = BreakStatement(lexer);
    // print ('Finished BreakStatement');
    caseNum = 9;
  }

  /// <continueStatement>
  void _case10(Lexer lexer) {
    // print ('Started ContinueStatement');
    continueStatement = ContinueStatement(lexer);
    // print ('Finished ContinueStatement');
    caseNum = 10;
  }

  /// <returnStatement>
  void _case11(Lexer lexer) {
    // print ('Started ReturnStatement');
    returnStatement = ReturnStatement(lexer);
    // print ('Finished ReturnStatement');
    caseNum = 11;
  }

  /// <yieldStatement>
  void _case12(Lexer lexer) {
    // print ('Started YieldStatement');
    yieldStatement = YieldStatement(lexer);
    // print ('Finished YieldStatement');
    caseNum = 12;
  }

  /// <yieldEachStatement>
  void _case13(Lexer lexer) {
    // print ('Started YieldEachStatement');
    yieldEachStatement = YieldEachStatement(lexer);
    // print ('Finished YieldEachStatement');
    caseNum = 13;
  }

  /// <expressionStatement>
  void _case14(Lexer lexer) {
    // print ('Started ExpressionStatement');
    expressionStatment = ExpressionStatment(lexer);
    // print ('Finished ExpressionStatement');
    caseNum = 14;
  }

  /// <assertStatement>
  void _case15(Lexer lexer) {
    // print ('Started AssertStatement');
    assertStatement = AssertStatement(lexer);
    // print ('Finished AssertStatement');
    caseNum = 15;
  }

  /// <localFunctionDeclaration
  void _case16(Lexer lexer) {
    // print ('Started LocalFunctionStatement');
    localFunctionDeclaration = LocalFunctionDeclaration(lexer);
    // print ('Finished LocalFunctionStatement');
    caseNum = 16;
  }

  String toString() {
    switch (caseNum) {
      case 0:
        return '$block';
        break;
      case 1:
        return '$localVariableDeclaration';
        break;
      case 2:
        return '$forStatement';
        break;
      case 3:
        return '$whileStatement';
        break;
      case 4:
        return '$doStatement';
        break;
      case 5:
        return '$switchStatement';
        break;
      case 6:
        return '$ifStatement';
        break;
      case 7:
        return '$rethrowStatement';
        break;
      case 8:
        return '$tryStatement';
        break;
      case 9:
        return '$breakStatement';
        break;
      case 10:
        return '$continueStatement';
        break;
      case 11:
        return '$returnStatement';
        break;
      case 12:
        return '$yieldStatement';
        break;
      case 13:
        return '$yieldEachStatement';
        break;
      case 14:
        return '$expressionStatment';
        break;
      case 15:
        return '$assertStatement';
        break;
      case 16:
        return '$localFunctionDeclaration';
        break;
    }
    return '';
  }
}
